<template>
    <div class="device-status">
        <div class="header">
            <div class="header-title">设备运行状态</div>
        </div>
        <div class="item-container">
            <div v-for="(item, index) in propertyValue" :key="index" class="item" :class="{'warning-bg': item.status}" @click="propertyClick(item)">
                <img :src="getImage(PROPERTY_ICON[item.id])" alt="" />
                <div>
                    <div class="title" :class="{'warning': item.status}">
                        {{ item?.value?.formatValue }} {{ item.unit }}
                        <img v-if="item.status" :src="getImage('/device-overview/kqjc/warning@2x.png')" alt="" />
                    </div>
                    <span class="desc">{{ item.name }}</span>
                    <span class="desc">{{ item.timeString }}</span>
                </div>
            </div>
        </div>
    </div>
</template>
<script lang="ts" name="DeviceRuningStatus" setup>
import { getImage } from '@/utils/comm';
import { PROPERTY_ICON } from '@/utils/consts';
const emits = defineEmits(['propertyClick']);
const status = ref<any>([]);

const props = defineProps({
    propertyValue: {
        type: Object,
        default: () => {}
    }
});
const propertyClick = (p:any)=>{
     emits('propertyClick', p)
}


onMounted(() => {
    status.value = [{
        imageUrl: "SF6@2x.png",
        value: "45.22",
        unit: "六氟化硫",
        desc: "PPM",
        status: 0
    },{
        imageUrl: "O2@2x.png",
        value: "45.3%",
        unit: "VOC",
        desc: "氧气",
        status: 0
    },{
        imageUrl: "PM10@2x.png",
        value: "55.0",
        unit: "微克",
        desc: "",
        status: 0
    },{
        imageUrl: "PM2.5@2x.png",
        value: "46.0",
        unit: "ug/m³",
        desc: "PM2.5",
        status: 0
    },{
        imageUrl: "tvoc@2x.png",
        value: "1646.0",
        unit: "",
        desc: "TVOC",
        status: 0
    },{
        imageUrl: "NO2@2x.png",
        value: "1127.0",
        unit: "",
        desc: "二氧化氮",
        status: 0
    },{
        imageUrl: "WD@2x.png",
        value: "24.8",
        unit: "℃",
        desc: "温度",
        status: 1
    },{
        imageUrl: "SD@2x.png",
        value: "24.7",
        unit: "%RH",
        desc: "湿度",
        status: 1
    },{
        imageUrl: "JQ@2x.png",
        value: "139.0",
        unit: "",
        desc: "甲醛",
        status: 0
    },{
        imageUrl: "O3@2x.png",
        value: "51",
        unit: "",
        desc: "臭氧",
        status: 0
    }];
});

// const props = defineProps({});
</script>
<style scoped lang="less">
.device-status {
    width: 100%;
    height: 100%;
    padding: 16px;
    background: #ffffff;
    box-shadow: 0px 2px 6px 0px #cccccc;
    border-radius: 4px 4px 4px 4px;
    .header {
        display: flex;
        align-items: center;
        justify-content: space-between;
        .header-title {
            border-left: 3px solid #3468ff;
            padding-left: 8px;
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 23px;
        }
    }
    .item-container {
        display: flex;
        justify-content: space-around;
        flex-wrap: wrap;
        .item {
            display: flex;
            padding: 10px;
            margin-top: 20px;
            width: calc(33.33% - 30px);
            height: 64px;
            background: #ffffff;
            box-shadow: 0px 0px 4px 0px rgba(136, 136, 136, 0.25);
            border-radius: 4px 4px 4px 4px;
            &.warning-bg {
                background-image: url('/images/device-overview/kqjc/Frame74@2x.png');
                background-size: 100% 100%;
            }

            img {
                width: 44px;
                height: 44px;
                margin-right: 8px;
            }
            .title {
                font-size: 18px;
                font-family: PingFang SC-Medium, PingFang SC;
                font-weight: 500;
                color: #333333;
                line-height: 20px;

                &.warning {
                    color: #FA3E2E;
                }
                img {
                    width: 14px;
                    height: 14px;
                }
            }
            .desc {
                font-size: 14px;
                font-family: PingFang SC-Medium, PingFang SC;
                font-weight: 500;
                color: #828282;
                line-height: 20px;
            }
        }
    }
}
</style>
